use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.006008
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib  ) );
__DATA__
shantanu
bhadoria
GyroScope
getRawReading
CBus
CBusDevicePath
CDevice
CDeviceAddress
XZero
YZero
ZZero
atleast
getReading
gyroscopeGain
lastReadingTime
timeDrift
getReadingDegreesPerSecond
getReadingRadiansPerSecond
xZero
yZero
zZero
radians
Shantanu
Bhadoria
at
cpan
dott
org
lib
Device
L3GD20
Gyroscope
